/*! 
 * \file   kgripper.c  Khepera3 Gripper            
 *
 * \brief 
 *         various Gripper commands. 
 *         
 *        
 * \author   Julien Tharin (K-Team SA)                               
 *
 * \note     Copyright (C) 2010 K-TEAM SA
 * \bug      none discovered.                                         
 * \todo     nothing.
 */

#ifndef kgripper_h
#define kgripper_h

#include <korebot/korebot.h>

												

/*--------------------------------------------------------------------*/
/*! initGripper open the various required handle to the both i2c devices 
 * on the Gripper using knet_open from the knet.c libkorebot's modules.
 *
 * \return A value :
 *      - 1 if success
 *      - 0 if any error
 */
int initGripper( void );



/*--------------------------------------------------------------------*/
/*! revisionOS retrieves the Gripper os version using kb_gripper.c library.
 */
int kgriprevisionOS( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! status return all the value of the Gripper using kb_gripper.c library.
 */
int status( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! movearm function set a new position order for the Arm of the Gripper using kb_gripper.c library.
 */
int movearm( int position);

/*--------------------------------------------------------------------*/
/*! movegrip function set a new position order for the Finger of the Gripper using kb_gripper.c library.
 */
int movegrip( int position);


/*--------------------------------------------------------------------*/
/*! get function will move the gripper to get an object (=1) or release it (= 0) using kb_gripper.c library.
 */
int get( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! grip function will move the gripper n times (0 = infiny) using kb_gripper.c library.
 */
int grip( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! demo function will move the gripper n times (0 = infiny) using kb_gripper.c library.
 */
int demo( int argc, char * argv[], void * data);


/*--------------------------------------------------------------------*/
/*! sensor return all the value of the sensors in the Gripper finger using kb_gripper.c library.
 */
int sensor( int argc, char * argv[], void * data);


// get gripper sensor distance
// input: sensor index: 0 = left, 1 = right 
// ouput: sensord distance 0 to 170
int get_gripper_sensor(int index);

/*--------------------------------------------------------------------*/
/*! setTorque define the maximal Torque use by the finger to grip an object using kb_gripper.c library.
 */
int setTorque( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! setMaxSpeed define the maximal speed of the arm gripper using kb_gripper.c library.
 */
int setMaxSpeed( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! searchLimit start the mechanical limit search using kb_gripper.c library.
 */
int searchLimit( int argc, char * argv[], void * data);



#endif
