/*! 
 * \file   khepera3.c  Khepera3              
 *
 * \brief 
 *         appli 
 *         
 *        
 * \author   Julien Tharin (K-Team SA)                               
 *
 * \note     Copyright (C) 2010 K-TEAM SA
 * \bug      none discovered.                                         
 * \todo     nothing.
 */

#ifndef khepera3_h
#define khepera3_h


#include <korebot/korebot.h>


/*--------------------------------------------------------------------*/
/*! initMot initializes then configures the motor control
 * unit.
 *
 * \return A value :
 *      - 1 if success
 *      - 0 if any error
 *   
 */
int initMot(knet_dev_t *hDev);
													

/*--------------------------------------------------------------------*/
/*! initKH3 initialize various things in the kh3 then
 * sequentialy open the various required handle to the three i2c devices 
 * on the khepera3 using knet_open from the knet.c libkorebot's modules.
 * Finaly, this function initializes then configures the motor control
 * unit.
 *
 * \return A value :
 *      - 0 if success
 *      - <0 if any error
 */
int initKH3( void ); 


/*--------------------------------------------------------------------*/
/*! proxIR retrieves proximity ir measure using kb_khepera3.c library.
	input: ir_index = index 0 to 10
	output: <0 : error
					>=0: sensor value
 */
int proxIR( int ir_index);
		
/*--------------------------------------------------------------------*/
/*! ambIR retrieves ambiant ir measure using kb_khepera3.c library.
 */
int ambIR( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! voltageBAT retrieves the battery voltage using kb_khepera3.c library.
 */
int voltageBAT( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! tstampRST resets the relative time stamp using kb_khepera3.c library.
 */
int tstampRST( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! revisionOS retrieves the khepera3 os version using kb_khepera3.c library.
 */
int kh3revisionOS( int argc, char * argv[], void * data);

/*--------------------------------------------------------------------*/
/*! configureOS configures various parameters inside the kh3 firmware
 *  using kb_khepera3.c library.
 *
 *  \param 1st first param (argv[1]) is the index pointing in configuration array.
 *  \param 2nd the second param (argv[2]) is the value to store where the index point at.
 *  
 */
int configureOS( int argc, char * argv[], void * data);
  
/*--------------------------------------------------------------------*/
/*! measureUS retrieves ultrasonic measure from a given transceiver.
 *
 * input: us_index = index 1 to 5
 * output: <0 : error
 *				>=0: sensor value
 */
int measureUS( int us_index);


/*--------------------------------------------------------------------*/
/*! motSpeed configures the motor controller speed in the engine control unit.
 *
 *  \param 1st first param (argv[1]) is the motor1 speed.
 *  \param 2nd second param (argv[2]) is the motor2 speed.
 *
 */
int motSpeed(int left_speed, int right_speed);

/*--------------------------------------------------------------------*/
/*! motMove configures the motor controller position in the engine control unit.
 *
 *  \param 1st first param (argv[1]) is the motor1 position.
 *  \param 2nd second param (argv[2]) is the motor2 position.
 *
 */
int motMove( int argc, char *argv[], void *data);

/*--------------------------------------------------------------------*/
/*! motStop stops the motor  in the engine control unit.
 *
 *  \param none.
 */
int motStop( int argc, char *argv[], void *data);
	  
/*--------------------------------------------------------------------*/
/*! Braintenberg demo program
 *
 *  \param none.
 */

#define BR_IRGAIN 30
#define fwSpeed 20
#define MIN_SPEED 10
#define RotSpeedL 50
#define RotSpeedR -50
 
int braitenbergAvoidance( int argc , char * argv[] , void * data);

#endif
